@@ -25,6 +25,9 @@ class ContextError(Exception):
     """Context execution error"""
     pass
 
+class UnsupportedTypeError(Warning):
+    """Type not supported error"""
+    pass
 
 class StateError(Exception):
     """State error"""
@@ -34,3 +37,11 @@ class StateError(Exception):
 class ServiceNetworkError(Exception):
     """Service networking error"""
     pass
+
+class NetworkFrameError(Exception):
+    """Networking frame error"""
+    pass
+
+class DataError(Exception):
+    """Networking frame error"""
+    pass
