@@ -24,8 +24,14 @@ from pathlib import Path
 import traceback
 # REFACTOR: remove this in favor of a better env setup
 replication_lib = Path(os.path.dirname(os.path.realpath(__file__)))
-sys.path.append(str(replication_lib.parent))
-sys.path.append(str(replication_lib.parent.parent))
+
+try:
+    import deepdiff
+    import zmq
+except ImportError:
+    sys.path.insert(0, str(replication_lib.parent.parent))
+
+sys.path.insert(0, str(replication_lib.parent))
 
 import copy
 import logging
