@@ -16,71 +16,55 @@
 # ##### END GPL LICENSE BLOCK #####
 
 
-import logging
-import threading
-import time
-import zmq
 import argparse
-import uuid
-import sys
+import logging
 import os
+import sys
+import uuid
 from pathlib import Path
 
-# Quick ugly fix.
+
+
+# REFACTOR: remove this in favor of a better env setup
 replication_lib = Path(os.path.dirname(os.path.realpath(__file__)))
 sys.path.append(str(replication_lib.parent))
-# TODO: organise modules properly
+sys.path.append(str(replication_lib.parent.parent))
 
-from replication.service import Service
 from replication.constants import CONNECTION_TIMEOUT
-from replication.utils import assert_parent_process_running
 
 logger = logging.getLogger(__name__)
-class ClientTTL(Service):
-    def __init__(
-            self,
-            context=zmq.Context(),
-            address="127.0.0.1",
-            id=None,
-            port=5562,
-            ipc_port=5562,
-            timeout=CONNECTION_TIMEOUT):
 
-        Service.__init__(
-            self,
-            ipc_port=ipc_port,
-            name="TTL"
-        )
-        # Networking
-        self._id = uuid.UUID(id).bytes 
+import zmq
 
-        self._command = self.context.socket(zmq.DEALER)
-        self._command.setsockopt(zmq.IDENTITY, self._id)
-        self._command.connect(f"tcp://{address}:{port+3}")
-        self._command.linger = 0
-        self._loop_interval = timeout+1000
+def heartbeat(address="127.0.0.1",
+              id=None,
+              port=5562,
+              timeout=CONNECTION_TIMEOUT):
+    contex = zmq.Context()
+    command = contex.socket(zmq.DEALER)
+    command.setsockopt(zmq.IDENTITY, uuid.UUID(id).bytes)
+    command.connect(f"tcp://{address}:{port+2}")
+    command.linger = 0
+    loop_interval = timeout+1000
 
-        self.poller.register(self._command, zmq.POLLIN)
+    poller = zmq.Poller()
+    poller.register(command, zmq.POLLIN)
 
-        self._command.send(b"INIT")
-        
-        self.start()
+    command.send(b"INIT")
+    logging.info("TTL running")
+    while True:
+        sockets = dict(poller.poll(loop_interval))
 
-    def main(self, sockets):
-        assert_parent_process_running()
-   
-        if self._command in sockets:
-            self._command.recv()
-            self._command.send(b"PONG")
+        if command in sockets:
+            command.recv()
+            command.send(b"PONG")
         else:
-            self.notify(['EVENT/DISCONNECT', {'reason':'connection timeout'}])         
-
-    def stop(self):
-        self._command.close()
+            command.close()
+            exit(0)
 
 
 if __name__ == "__main__":
-    
+
     parser = argparse.ArgumentParser()
     parser.add_argument('-p', '--port', required=True,
                         help="port to listen")
@@ -90,15 +74,10 @@ if __name__ == "__main__":
                         help="user id")
     parser.add_argument('-t', '--timeout', required=True,
                         help="timeout before disconnection")
-    parser.add_argument('-tp', '--ttlport', required=True,
-                        help="ttl port")
 
     args = parser.parse_args()
 
-    cli_ttl_instance = ClientTTL(
-        port=int(args.port),
-        address=args.destination,
-        id=args.id,
-        timeout=int(args.timeout),
-        ipc_port=int(args.ttlport)
-    )
+    heartbeat(port=int(args.port),
+              address=args.destination,
+              id=args.id,
+              timeout=int(args.timeout))
